==> gcjwebplugin-0.1.3.tar.gz: gcjwebplugin-0.1.3/src/gnu/gcjwebplugin/AppletWarning.java <==
/* gcjwebplugin - Webbrowser plugin to execute Java (tm) applets.
   Copyright (C) 2003  Michael Koch <konqueror@gmx.de>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307  USA

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package gnu.gcjwebplugin;

import java.awt.BorderLayout;
import java.awt.Button;
import java.awt.Frame;
import java.awt.TextArea;

public class AppletWarning extends Frame
{
  public AppletWarning()
  {
    setLayout (new BorderLayout());
    
    TextArea text = new TextArea (
      "WARNING: The current version of this applet plugin does not provide " +
      "a security manager capable of handling Java (tm) applets. Applets " +
      "have UNRESTRICTED access to your computer. This means they can do " +
      "anything you can do, like deleting all your important data.",
      20, 5, TextArea.SCROLLBARS_NONE);
    text.setEditable (false);
    add (text, BorderLayout.CENTER);

    add (new Button ("Continue"), BorderLayout.SOUTH);
  }
}

==> gcjwebplugin-0.2.2.tar.gz: gcjwebplugin-0.2.2/src/gnu/gcjwebplugin/AppletWarning.java <==
/* gcjwebplugin - Webbrowser plugin to execute Java (tm) applets.
   Copyright (C) 2003, 2004  Michael Koch <konqueror@gmx.de>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307  USA

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package gnu.gcjwebplugin;

import java.awt.BorderLayout;
import java.awt.Button;
import java.awt.Frame;
import java.awt.TextArea;


/**
 * @author Michael Koch (konqueror@gmx.de)
 */
public class AppletWarning extends Frame
{
  /**
   * Contructs a frame showing a security warning.
   */
  public AppletWarning()
  {
    setLayout(new BorderLayout());

    TextArea text =
      new TextArea("WARNING: The current version of this applet plugin does not provide "
                   + "a security manager capable of handling Java (tm) applets. Applets "
                   + "have UNRESTRICTED access to your computer. This means they can do "
                   + "anything you can do, like deleting all your important data.",
                   20, 5, TextArea.SCROLLBARS_NONE);
    text.setEditable(false);
    add(text, BorderLayout.CENTER);

    add(new Button("Continue"), BorderLayout.SOUTH);
  }
}
